/**
 * MainPanel.java 
 *
 * This is a panel which divides the area below the banner into a right panel where
 * the list form and the new forms are shown and the option frame which is the narrow
 * left frame. It uses a border layout to place the left and right panels accordingly.
 * This also implements the ActionListener for the buttons present in the left frame
 * calls the showcard method in the right panel to display the appropriate panel for
 * the appropriate button click. The events are propogated as shown below
 *       
 *                           MainPanel (Event processor)
 *                               |
 *          ^                   / \ 
 *          | Button clicks    /   \  | display cards
 *                            /	    \ V
 *                           /       \
 *                          /         \
 *                      LeftPanel  RightPanel
 *
 * @author xjqiu@npac.syr.edu
 *
 */

import java.awt.*;
import java.awt.event.*;

public class MainPanel extends Panel
     implements ActionListener { // class definition

 private StatusWin swin; // status window for displaying the status of communication
 private LeftPanel lt; //left panel 
 private RightPanel rt; // right panel

/**
 * Constructor for the class. This sets out the layout for the class and adds the 
 * panels
 */

 public MainPanel() {

     setLayout(new BorderLayout()); // use a border layout

     lt = new LeftPanel(this);  //create a  left page
     rt = new RightPanel(); // create s right page
 
     add(lt,"West");   // place the left panel to the west
     add(rt,"Center"); // add the right panel to the center
 }

/**
 * This is the action Listener implementation that the button clicks in the 
 * left frame responds to. Depending on which button is clicked the corresponding card
 * is shown in the right. 
 */
 public void actionPerformed(ActionEvent e) {
    Button b = (Button) e.getSource(); // get the button source
    String tmpstr = b.getLabel(); //get the name of the button and 
    boolean openflag;  //true for open successfully
    boolean closeflag; //trun for close successfully
 
    if (tmpstr.trim().equals("Open")) { //open database file
         try {
         		openflag = CourseApplet.obj.open(); //call remote method
         		if (openflag){
         	 		System.out.println("MainPanel->actionPerformed: Connection to Database has been opened."); 
		 		}
		 }catch (Exception ex) {  
        		System.err.println("MainPanel->actionPerformed: Conneciton Open to DB error..." );
        		ex.printStackTrace();
         }
     }// end of openif 

    if (tmpstr.trim().equals("Close")) { //close database file
         try {
         		closeflag = CourseApplet.obj.close(); //call remote method
         		if (closeflag){
         	 		System.out.println("MainPanel->actionPerformed: Connection to DB has been closed."); 
		 		}
		 }catch (Exception ex) {  
        		System.err.println("MainPanel->actionPerformed: Conneciton Close to DB error..." );
        		ex.printStackTrace();
         }
    } //end of closeif 
   
    rt.showCard(tmpstr); // call show card in the right panel to display the appropriate card
 }
} // end of class
